==> fastapi_guard_agent-0.0.1-py3-none-any.whl: guard_agent/protocols.py <==
from typing import Any, Protocol, runtime_checkable

from guard_agent.models import AgentStatus, DynamicRules, SecurityEvent, SecurityMetric


@runtime_checkable
class RedisHandlerProtocol(Protocol):
    """Protocol for Redis handlers - compatible with fastapi-guard."""

    async def get_key(self, namespace: str, key: str) -> Any: ...
    async def set_key(
        self, namespace: str, key: str, value: Any, ttl: int | None = None
    ) -> bool | None: ...
    async def delete_key(self, namespace: str, key: str) -> bool: ...
    async def keys(self, pattern: str) -> list[str] | None: ...
    async def initialize(self) -> None: ...


@runtime_checkable
class TransportProtocol(Protocol):
    """Protocol for transport layer implementations."""

    async def send_events(self, events: list[SecurityEvent]) -> bool: ...
    async def send_metrics(self, metrics: list[SecurityMetric]) -> bool: ...
    async def fetch_dynamic_rules(self) -> DynamicRules | None: ...
    async def send_status(self, status: AgentStatus) -> bool: ...


@runtime_checkable
class BufferProtocol(Protocol):
    """Protocol for event buffering implementations."""

    async def add_event(self, event: SecurityEvent) -> None: ...
    async def add_metric(self, metric: SecurityMetric) -> None: ...
    async def flush_events(self) -> list[SecurityEvent]: ...
    async def flush_metrics(self) -> list[SecurityMetric]: ...
    async def get_buffer_size(self) -> int: ...
    async def clear_buffer(self) -> None: ...


@runtime_checkable
class AgentHandlerProtocol(Protocol):
    """Protocol for agent handlers - follows existing fastapi-guard pattern."""

    async def initialize_redis(self, redis_handler: RedisHandlerProtocol) -> None: ...
    async def send_event(self, event: SecurityEvent) -> None: ...
    async def send_metric(self, metric: SecurityMetric) -> None: ...
    async def get_dynamic_rules(self) -> DynamicRules | None: ...
    async def flush_buffer(self) -> None: ...
    async def get_status(self) -> AgentStatus: ...
    async def close(self) -> None: ...

==> fastapi_guard_agent-0.1.1-py3-none-any.whl: guard_agent/protocols.py <==
from typing import Any, Protocol, runtime_checkable

from guard_agent.models import AgentStatus, DynamicRules, SecurityEvent, SecurityMetric


@runtime_checkable
class RedisHandlerProtocol(Protocol):
    """Protocol for Redis handlers - compatible with fastapi-guard."""

    async def get_key(self, namespace: str, key: str) -> Any: ...
    async def set_key(
        self, namespace: str, key: str, value: Any, ttl: int | None = None
    ) -> bool | None: ...
    async def delete(self, namespace: str, key: str) -> int | None: ...
    async def keys(self, pattern: str) -> list[str] | None: ...
    async def initialize(self) -> None: ...
    def get_connection(self) -> Any: ...


@runtime_checkable
class TransportProtocol(Protocol):
    """Protocol for transport layer implementations."""

    async def send_events(self, events: list[SecurityEvent]) -> bool: ...
    async def send_metrics(self, metrics: list[SecurityMetric]) -> bool: ...
    async def fetch_dynamic_rules(self) -> DynamicRules | None: ...
    async def send_status(self, status: AgentStatus) -> bool: ...


@runtime_checkable
class BufferProtocol(Protocol):
    """Protocol for event buffering implementations."""

    async def add_event(self, event: SecurityEvent) -> None: ...
    async def add_metric(self, metric: SecurityMetric) -> None: ...
    async def flush_events(self) -> list[SecurityEvent]: ...
    async def flush_metrics(self) -> list[SecurityMetric]: ...
    async def get_buffer_size(self) -> int: ...
    async def clear_buffer(self) -> None: ...


@runtime_checkable
class AgentHandlerProtocol(Protocol):
    """Protocol for agent handlers - follows existing fastapi-guard pattern."""

    async def initialize_redis(self, redis_handler: RedisHandlerProtocol) -> None: ...
    async def send_event(self, event: SecurityEvent) -> None: ...
    async def send_metric(self, metric: SecurityMetric) -> None: ...
    async def get_dynamic_rules(self) -> DynamicRules | None: ...
    async def flush_buffer(self) -> None: ...
    async def get_status(self) -> AgentStatus: ...
    async def close(self) -> None: ...
